@@ -32,6 +32,7 @@ class QchDialogWidget : public QDialog, public QDeclarativeParserStatus
     
     Q_PROPERTY(QDeclarativeListProperty<QDeclarativeItem> children READ children)
     Q_PROPERTY(QDeclarativeListProperty<QObject> data READ data)
+    Q_PROPERTY(QDeclarativeItem* contentItem READ contentItem CONSTANT)
     Q_PROPERTY(int height READ height WRITE setFixedHeight NOTIFY sizeChanged)
     Q_PROPERTY(bool showProgressIndicator READ showProgressIndicator WRITE setShowProgressIndicator
                NOTIFY showProgressIndicatorChanged)
@@ -55,6 +56,8 @@ public:
     QDeclarativeListProperty<QDeclarativeItem> children();
     QDeclarativeListProperty<QObject> data();
     
+    QDeclarativeItem* contentItem() const;
+    
     bool showProgressIndicator() const;
     void setShowProgressIndicator(bool enabled);
     
@@ -92,6 +95,7 @@ class QchDialog : public QObject, public QDeclarativeParserStatus
     
     Q_PROPERTY(QDeclarativeListProperty<QDeclarativeItem> children READ children)
     Q_PROPERTY(QDeclarativeListProperty<QObject> data READ data)
+    Q_PROPERTY(QDeclarativeItem* contentItem READ contentItem CONSTANT)
     Q_PROPERTY(int height READ height WRITE setHeight NOTIFY sizeChanged)
     Q_PROPERTY(bool modal READ isModal WRITE setModal NOTIFY modalChanged)
     Q_PROPERTY(QObject* parent READ parent WRITE setParent NOTIFY parentChanged)
@@ -101,6 +105,7 @@ class QchDialog : public QObject, public QDeclarativeParserStatus
     Q_PROPERTY(QchDialogStatus::Status status READ status NOTIFY statusChanged)
     Q_PROPERTY(QString title READ title WRITE setTitle NOTIFY titleChanged)
     Q_PROPERTY(bool visible READ isVisible WRITE setVisible NOTIFY visibleChanged)
+    Q_PROPERTY(int width READ width WRITE setWidth NOTIFY sizeChanged)
     
     Q_ENUMS(QDialog::DialogCode)
     
@@ -115,6 +120,8 @@ public:
     QDeclarativeListProperty<QDeclarativeItem> children();
     QDeclarativeListProperty<QObject> data();
     
+    QDeclarativeItem* contentItem() const;
+    
     int height() const;
     void setHeight(int h);
         
@@ -134,6 +141,9 @@ public:
     
     bool isVisible() const;
     void setVisible(bool v);
+    
+    int width() const;
+    void setWidth(int w);
 
 public Q_SLOTS:
     void accept();
